@@ -463,3 +463,286 @@ def getPeriodEra(period):
     else:
         return "Invalid period"
 
+
+def fancyEnglish(text):
+    # Define a dictionary to map modern words to older equivalents
+    word_dict = {
+        "you": "thou",
+        "your": "thy",
+        "yours": "thine",
+        "the": "ye",
+        "hello": "hail",
+        "hi": "hail",
+        "hey": "hail",
+        "yes": "aye",
+        "no": "nay",
+        "goodbye": "farewell",
+        "friend": "comrade",
+        "mate": "comrade",
+        "buddy": "comrade",
+        "sorry": "pardon",
+        "sorry,": "pardon,",
+        "thanks": "thou art thanked",
+        "thank": "thou art thanked",
+        "thank you": "thou art thanked",
+        "please": "prithee",
+        "okay": "verily",
+        "ok": "verily",
+        "alright": "verily",
+        "are": "art",
+    }
+
+    # Split the text into words and iterate over each word
+    words = text.split()
+    old_style_words = []
+    punctuation = "!@#$%^&*()<>?:;,./"
+    for word in words:
+        # Preserve the original capitalization of the word
+        is_capitalized = word.istitle() or word.isupper()
+        # Split the word based on punctuation
+        parts = [word] if word[-1] not in punctuation else [word[:-1], word[-1]]
+        old_style_parts = []
+        for part in parts:
+            # Check if the part is a punctuation mark
+            if part in punctuation:
+                old_style_parts.append(part)
+            else:
+                # Check if the part is in the dictionary, and replace it if it is
+                old_style_part = word_dict.get(part.lower(), part)
+                # Capitalize the first letter of the old-style part if necessary
+                if old_style_part != part:
+                    if is_capitalized:
+                        old_style_part = old_style_part.capitalize()
+                    else:
+                        old_style_part = old_style_part.lower()
+                old_style_parts.append(old_style_part)
+        # Combine the old-style parts into a word and add it to the list of old-style words
+        old_style_word = "".join(old_style_parts)
+        old_style_words.append(old_style_word)
+
+    # Combine the old-style words into a string and return it
+    return " ".join(old_style_words)
+
+
+def modernEnglish(text):
+    # Define a dictionary to map older words to modern equivalents
+    word_dict = {
+        "thou": "you",
+        "thy": "your",
+        "thine": "yours",
+        "ye": "the",
+        "hail": "hello",
+        "aye": "yes",
+        "nay": "no",
+        "farewell": "goodbye",
+        "comrade": "friend",
+        "pardon": "sorry",
+        "pardon,": "sorry,",
+        "thou art thanked": "thank you",
+        "prithee": "please",
+        "verily": "okay",
+        "art": "are",
+    }
+
+    # Split the text into words and iterate over each word
+    words = text.split()
+    modern_style_words = []
+    punctuation = "!@#$%^&*()<>?:;,./"
+    for word in words:
+        # Preserve the original capitalization of the word
+        is_capitalized = word.istitle() or word.isupper()
+        # Split the word based on punctuation
+        parts = [word] if word[-1] not in punctuation else [word[:-1], word[-1]]
+        modern_style_parts = []
+        for part in parts:
+            # Check if the part is a punctuation mark
+            if part in punctuation:
+                modern_style_parts.append(part)
+            else:
+                # Check if the part is in the dictionary, and replace it if it is
+                modern_style_part = word_dict.get(part.lower(), part)
+                # Capitalize the first letter of the modern-style part if necessary
+                if modern_style_part != part:
+                    if is_capitalized:
+                        modern_style_part = modern_style_part.capitalize()
+                    else:
+                        modern_style_part = modern_style_part.lower()
+                modern_style_parts.append(modern_style_part)
+        # Combine the modern-style parts into a word and add it to the list of modern-style words
+        modern_style_word = "".join(modern_style_parts)
+        modern_style_words.append(modern_style_word)
+
+    # Combine the modern-style words into a string and return it
+    return " ".join(modern_style_words)
+
+
+def toGlyph(text, hieroglyphics_dict=None):
+    # Initialize an empty string to store the hieroglyphics
+    if hieroglyphics_dict is None:
+        hieroglyphics_dict = {
+            "A": "\U00013000",
+            "B": "\U00013001",
+            "C": "\U00013002",
+            "D": "\U00013003",
+            "E": "\U00013004",
+            "F": "\U00013005",
+            "G": "\U00013006",
+            "H": "\U00013007",
+            "I": "\U00013008",
+            "J": "\U00013009",
+            "K": "\U0001300A",
+            "L": "\U0001300B",
+            "M": "\U0001300C",
+            "N": "\U0001300D",
+            "O": "\U0001300E",
+            "P": "\U0001300F",
+            "Q": "\U00013010",
+            "R": "\U00013011",
+            "S": "\U00013012",
+            "T": "\U00013013",
+            "U": "\U00013014",
+            "V": "\U00013015",
+            "W": "\U00013016",
+            "X": "\U00013017",
+            "Y": "\U00013018",
+            "Z": "\U00013019",
+            "a": "\U0001301A",
+            "b": "\U0001301B",
+            "c": "\U0001301C",
+            "d": "\U0001301D",
+            "e": "\U0001301E",
+            "f": "\U0001301F",
+            "g": "\U00013020",
+            "h": "\U00013021",
+            "i": "\U00013022",
+            "j": "\U00013023",
+            "k": "\U00013024",
+            "l": "\U00013025",
+            "m": "\U00013026",
+            "n": "\U00013027",
+            "o": "\U00013028",
+            "p": "\U00013029",
+            "q": "\U0001302A",
+            "r": "\U0001302B",
+            "s": "\U0001302C",
+            "t": "\U0001302D",
+            "u": "\U0001302E",
+            "v": "\U0001302F",
+            "w": "\U00013030",
+            "x": "\U00013031",
+            "y": "\U00013032",
+            "z": "\U00013033",
+            " ": "\U00013034",
+            ".": "\U00013035",
+            ",": "\U00013036",
+            ";": "\U00013037",
+            ":": "\U00013038",
+            "!": "\U00013039",
+            "?": "\U0001303A",
+            "(": "\U0001303B",
+            ")": "\U0001303C",
+            "[": "\U0001303D",
+            "]": "\U0001303E",
+            "{": "\U0001303F",
+            "}": "\U00013040",
+            "<": "\U00013041",
+            ">": "\U00013042",
+            "/": "\U00013043",
+            "\\": "\U00013044",
+            "|": "\U00013045",
+        }
+    hieroglyphics_text = ""
+    for char in text:
+        # Check if the character is in the dictionary
+        if char in hieroglyphics_dict:
+            # Append the corresponding hieroglyphic to the string
+            hieroglyphics_text += hieroglyphics_dict[char]
+        else:
+            # If the character is not in the dictionary, append it unchanged
+            hieroglyphics_text += char
+
+    # Return the hieroglyphics string
+    return hieroglyphics_text
+
+
+def getGlyphs():
+    hieroglyphics_dict = {
+        "A": "\U00013000",
+        "B": "\U00013001",
+        "C": "\U00013002",
+        "D": "\U00013003",
+        "E": "\U00013004",
+        "F": "\U00013005",
+        "G": "\U00013006",
+        "H": "\U00013007",
+        "I": "\U00013008",
+        "J": "\U00013009",
+        "K": "\U0001300A",
+        "L": "\U0001300B",
+        "M": "\U0001300C",
+        "N": "\U0001300D",
+        "O": "\U0001300E",
+        "P": "\U0001300F",
+        "Q": "\U00013010",
+        "R": "\U00013011",
+        "S": "\U00013012",
+        "T": "\U00013013",
+        "U": "\U00013014",
+        "V": "\U00013015",
+        "W": "\U00013016",
+        "X": "\U00013017",
+        "Y": "\U00013018",
+        "Z": "\U00013019",
+        "a": "\U0001301A",
+        "b": "\U0001301B",
+        "c": "\U0001301C",
+        "d": "\U0001301D",
+        "e": "\U0001301E",
+        "f": "\U0001301F",
+        "g": "\U00013020",
+        "h": "\U00013021",
+        "i": "\U00013022",
+        "j": "\U00013023",
+        "k": "\U00013024",
+        "l": "\U00013025",
+        "m": "\U00013026",
+        "n": "\U00013027",
+        "o": "\U00013028",
+        "p": "\U00013029",
+        "q": "\U0001302A",
+        "r": "\U0001302B",
+        "s": "\U0001302C",
+        "t": "\U0001302D",
+        "u": "\U0001302E",
+        "v": "\U0001302F",
+        "w": "\U00013030",
+        "x": "\U00013031",
+        "y": "\U00013032",
+        "z": "\U00013033",
+        " ": "\U00013034",
+        ".": "\U00013035",
+        ",": "\U00013036",
+        ";": "\U00013037",
+        ":": "\U00013038",
+        "!": "\U00013039",
+        "?": "\U0001303A",
+        "(": "\U0001303B",
+        ")": "\U0001303C",
+        "[": "\U0001303D",
+        "]": "\U0001303E",
+        "{": "\U0001303F",
+        "}": "\U00013040",
+        "<": "\U00013041",
+        ">": "\U00013042",
+        "/": "\U00013043",
+        "\\": "\U00013044",
+        "|": "\U00013045",
+    }
+    return hieroglyphics_dict
+
+
+def inverseDict(d):
+    """
+    Given a dictionary d, returns a new dictionary with the keys and values swapped.
+    """
+    return {v: k for k, v in d.items()}
